==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/tr-TR.pl <==
{
  am_pm_abbreviated => [
    "\N{U+00d6}\N{U+00d6}",
    "\N{U+00d6}S",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E a h:mm",
    Ehms => "E a h:mm:ss",
    Gy => "G y",
    GyMMM => "G MMM y",
    GyMMMEd => "G d MMM y E",
    GyMMMd => "G d MMM y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "d/MM E",
    MMM => "LLL",
    MMMEd => "d MMMM E",
    MMMMEd => "d MMMM E",
    "MMMMW-count-one" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
    "MMMMW-count-other" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "a h",
    hm => "a h:mm",
    hms => "a h:mm:ss",
    hmsv => "a h:mm:ss v",
    hmv => "a h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "d.M.y E",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "d MMM y E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd.MM.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "Y 'y\N{U+0131}l\N{U+0131}n\N{U+0131}n' w. 'haftas\N{U+0131}'",
    "yw-count-other" => "Y 'y\N{U+0131}l\N{U+0131}n\N{U+0131}n' w. 'haftas\N{U+0131}'",
  },
  code => "tr-TR",
  date_format_full => "d MMMM y EEEE",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Pzt",
    "Sal",
    "\N{U+00c7}ar",
    "Per",
    "Cum",
    "Cmt",
    "Paz",
  ],
  day_format_narrow => [
    "P",
    "S",
    "\N{U+00c7}",
    "P",
    "C",
    "C",
    "P",
  ],
  day_format_wide => [
    "Pazartesi",
    "Sal\N{U+0131}",
    "\N{U+00c7}ar\N{U+015f}amba",
    "Per\N{U+015f}embe",
    "Cuma",
    "Cumartesi",
    "Pazar",
  ],
  day_stand_alone_abbreviated => [
    "Pzt",
    "Sal",
    "\N{U+00c7}ar",
    "Per",
    "Cum",
    "Cmt",
    "Paz",
  ],
  day_stand_alone_narrow => [
    "P",
    "S",
    "\N{U+00c7}",
    "P",
    "C",
    "C",
    "P",
  ],
  day_stand_alone_wide => [
    "Pazartesi",
    "Sal\N{U+0131}",
    "\N{U+00c7}ar\N{U+015f}amba",
    "Per\N{U+015f}embe",
    "Cuma",
    "Cumartesi",
    "Pazar",
  ],
  era_abbreviated => [
    "M\N{U+00d6}",
    "MS",
  ],
  era_narrow => [
    "M\N{U+00d6}",
    "MS",
  ],
  era_wide => [
    "Milattan \N{U+00d6}nce",
    "Milattan Sonra",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d-%m-%Y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Turkish",
  month_format_abbreviated => [
    "Oca",
    "\N{U+015e}ub",
    "Mar",
    "Nis",
    "May",
    "Haz",
    "Tem",
    "A\N{U+011f}u",
    "Eyl",
    "Eki",
    "Kas",
    "Ara",
  ],
  month_format_narrow => [
    "O",
    "\N{U+015e}",
    "M",
    "N",
    "M",
    "H",
    "T",
    "A",
    "E",
    "E",
    "K",
    "A",
  ],
  month_format_wide => [
    "Ocak",
    "\N{U+015e}ubat",
    "Mart",
    "Nisan",
    "May\N{U+0131}s",
    "Haziran",
    "Temmuz",
    "A\N{U+011f}ustos",
    "Eyl\N{U+00fc}l",
    "Ekim",
    "Kas\N{U+0131}m",
    "Aral\N{U+0131}k",
  ],
  month_stand_alone_abbreviated => [
    "Oca",
    "\N{U+015e}ub",
    "Mar",
    "Nis",
    "May",
    "Haz",
    "Tem",
    "A\N{U+011f}u",
    "Eyl",
    "Eki",
    "Kas",
    "Ara",
  ],
  month_stand_alone_narrow => [
    "O",
    "\N{U+015e}",
    "M",
    "N",
    "M",
    "H",
    "T",
    "A",
    "E",
    "E",
    "K",
    "A",
  ],
  month_stand_alone_wide => [
    "Ocak",
    "\N{U+015e}ubat",
    "Mart",
    "Nisan",
    "May\N{U+0131}s",
    "Haziran",
    "Temmuz",
    "A\N{U+011f}ustos",
    "Eyl\N{U+00fc}l",
    "Ekim",
    "Kas\N{U+0131}m",
    "Aral\N{U+0131}k",
  ],
  name => "Turkish Turkey",
  native_language => "T\N{U+00fc}rk\N{U+00e7}e",
  native_name => "T\N{U+00fc}rk\N{U+00e7}e T\N{U+00fc}rkiye",
  native_script => undef,
  native_territory => "T\N{U+00fc}rkiye",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. \N{U+00e7}eyrek",
    "2. \N{U+00e7}eyrek",
    "3. \N{U+00e7}eyrek",
    "4. \N{U+00e7}eyrek",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+00e7}eyrek",
    "2. \N{U+00e7}eyrek",
    "3. \N{U+00e7}eyrek",
    "4. \N{U+00e7}eyrek",
  ],
  script => undef,
  territory => "Turkey",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/tr-TR.pl <==
{
  am_pm_abbreviated => [
    "\N{U+00d6}\N{U+00d6}",
    "\N{U+00d6}S",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E a\N{U+202f}h:mm",
    Ehms => "E a\N{U+202f}h:mm:ss",
    Gy => "G y",
    GyMMM => "G MMM y",
    GyMMMEd => "G d MMM y E",
    GyMMMd => "G d MMM y",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "d/MM E",
    MMM => "LLL",
    MMMEd => "d MMMM E",
    MMMMEd => "d MMMM E",
    "MMMMW-count-one" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
    "MMMMW-count-other" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "a\N{U+202f}h",
    hm => "a\N{U+202f}h:mm",
    hms => "a\N{U+202f}h:mm:ss",
    hmsv => "a\N{U+202f}h:mm:ss v",
    hmv => "a\N{U+202f}h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "d.M.y E",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "d MMM y E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd.MM.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "Y 'y\N{U+0131}l\N{U+0131}n\N{U+0131}n' w. 'haftas\N{U+0131}'",
    "yw-count-other" => "Y 'y\N{U+0131}l\N{U+0131}n\N{U+0131}n' w. 'haftas\N{U+0131}'",
  },
  code => "tr-TR",
  date_format_full => "d MMMM y EEEE",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Pzt",
    "Sal",
    "\N{U+00c7}ar",
    "Per",
    "Cum",
    "Cmt",
    "Paz",
  ],
  day_format_narrow => [
    "P",
    "S",
    "\N{U+00c7}",
    "P",
    "C",
    "C",
    "P",
  ],
  day_format_wide => [
    "Pazartesi",
    "Sal\N{U+0131}",
    "\N{U+00c7}ar\N{U+015f}amba",
    "Per\N{U+015f}embe",
    "Cuma",
    "Cumartesi",
    "Pazar",
  ],
  day_stand_alone_abbreviated => [
    "Pzt",
    "Sal",
    "\N{U+00c7}ar",
    "Per",
    "Cum",
    "Cmt",
    "Paz",
  ],
  day_stand_alone_narrow => [
    "P",
    "S",
    "\N{U+00c7}",
    "P",
    "C",
    "C",
    "P",
  ],
  day_stand_alone_wide => [
    "Pazartesi",
    "Sal\N{U+0131}",
    "\N{U+00c7}ar\N{U+015f}amba",
    "Per\N{U+015f}embe",
    "Cuma",
    "Cumartesi",
    "Pazar",
  ],
  era_abbreviated => [
    "M\N{U+00d6}",
    "MS",
  ],
  era_narrow => [
    "M\N{U+00d6}",
    "MS",
  ],
  era_wide => [
    "Milattan \N{U+00d6}nce",
    "Milattan Sonra",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d-%m-%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Turkish",
  month_format_abbreviated => [
    "Oca",
    "\N{U+015e}ub",
    "Mar",
    "Nis",
    "May",
    "Haz",
    "Tem",
    "A\N{U+011f}u",
    "Eyl",
    "Eki",
    "Kas",
    "Ara",
  ],
  month_format_narrow => [
    "O",
    "\N{U+015e}",
    "M",
    "N",
    "M",
    "H",
    "T",
    "A",
    "E",
    "E",
    "K",
    "A",
  ],
  month_format_wide => [
    "Ocak",
    "\N{U+015e}ubat",
    "Mart",
    "Nisan",
    "May\N{U+0131}s",
    "Haziran",
    "Temmuz",
    "A\N{U+011f}ustos",
    "Eyl\N{U+00fc}l",
    "Ekim",
    "Kas\N{U+0131}m",
    "Aral\N{U+0131}k",
  ],
  month_stand_alone_abbreviated => [
    "Oca",
    "\N{U+015e}ub",
    "Mar",
    "Nis",
    "May",
    "Haz",
    "Tem",
    "A\N{U+011f}u",
    "Eyl",
    "Eki",
    "Kas",
    "Ara",
  ],
  month_stand_alone_narrow => [
    "O",
    "\N{U+015e}",
    "M",
    "N",
    "M",
    "H",
    "T",
    "A",
    "E",
    "E",
    "K",
    "A",
  ],
  month_stand_alone_wide => [
    "Ocak",
    "\N{U+015e}ubat",
    "Mart",
    "Nisan",
    "May\N{U+0131}s",
    "Haziran",
    "Temmuz",
    "A\N{U+011f}ustos",
    "Eyl\N{U+00fc}l",
    "Ekim",
    "Kas\N{U+0131}m",
    "Aral\N{U+0131}k",
  ],
  name => "Turkish Turkey",
  native_language => "T\N{U+00fc}rk\N{U+00e7}e",
  native_name => "T\N{U+00fc}rk\N{U+00e7}e T\N{U+00fc}rkiye",
  native_script => undef,
  native_territory => "T\N{U+00fc}rkiye",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. \N{U+00e7}eyrek",
    "2. \N{U+00e7}eyrek",
    "3. \N{U+00e7}eyrek",
    "4. \N{U+00e7}eyrek",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+00e7}eyrek",
    "2. \N{U+00e7}eyrek",
    "3. \N{U+00e7}eyrek",
    "4. \N{U+00e7}eyrek",
  ],
  script => undef,
  territory => "Turkey",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
